<?php

namespace Litecms\StairStepSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\StairStepSetting\Http\Requests\StairStepSettingRequest;
use Litecms\StairStepSetting\Interfaces\StairStepSettingRepositoryInterface;
use Litecms\StairStepSetting\Models\StairStepSetting;

/**
 * Resource controller class for stair_step_setting.
 */
class StairStepSettingResourceController extends BaseController
{

    /**
     * Initialize stair_step_setting resource controller.
     *
     * @param type StairStepSettingRepositoryInterface $stair_step_setting
     *
     * @return null
     */
    public function __construct(StairStepSettingRepositoryInterface $stair_step_setting)
    {
        parent::__construct();
        $this->repository = $stair_step_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\StairStepSetting\Repositories\Criteria\StairStepSettingResourceCriteria::class);
    }

    /**
     * Display a list of stair_step_setting.
     *
     * @return Response
     */
    public function index(StairStepSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\StairStepSetting\Repositories\Presenter\StairStepSettingPresenter::class)
                ->$function();
        }

        $stair_step_settings = $this->repository->paginate();

        return $this->response->title(trans('stair_step_setting::stair_step_setting.names'))
            ->view('stair_step_setting::stair_step_setting.index', true)
            ->data(compact('stair_step_settings'))
            ->output();
    }

    /**
     * Display stair_step_setting.
     *
     * @param Request $request
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function show(StairStepSettingRequest $request, StairStepSetting $stair_step_setting)
    {

        if ($stair_step_setting->exists) {
            $view = 'stair_step_setting::stair_step_setting.show';
        } else {
            $view = 'stair_step_setting::stair_step_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('stair_step_setting::stair_step_setting.name'))
            ->data(compact('stair_step_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new stair_step_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(StairStepSettingRequest $request)
    {

        $stair_step_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('stair_step_setting::stair_step_setting.name')) 
            ->view('stair_step_setting::stair_step_setting.create', true) 
            ->data(compact('stair_step_setting'))
            ->output();
    }

    /**
     * Create new stair_step_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StairStepSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $stair_step_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('stair_step_setting::stair_step_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_setting/' . $stair_step_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/stair_step_setting/stair_step_setting'))
                ->redirect();
        }

    }

    /**
     * Show stair_step_setting for editing.
     *
     * @param Request $request
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function edit(StairStepSettingRequest $request, StairStepSetting $stair_step_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('stair_step_setting::stair_step_setting.name'))
            ->view('stair_step_setting::stair_step_setting.edit', true)
            ->data(compact('stair_step_setting'))
            ->output();
    }

    /**
     * Update the stair_step_setting.
     *
     * @param Request $request
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function update(StairStepSettingRequest $request, StairStepSetting $stair_step_setting)
    {
        try {
            $attributes = $request->all();

            $stair_step_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('stair_step_setting::stair_step_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_setting/' . $stair_step_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_step_setting/stair_step_setting/' . $stair_step_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the stair_step_setting.
     *
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function destroy(StairStepSettingRequest $request, StairStepSetting $stair_step_setting)
    {
        try {

            $stair_step_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_step_setting::stair_step_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('stair_step_setting/stair_step_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('stair_step_setting/stair_step_setting/' . $stair_step_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple stair_step_setting.
     *
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function delete(StairStepSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('stair_step_setting::stair_step_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('stair_step_setting/stair_step_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_step_setting/stair_step_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted stair_step_settings.
     *
     * @param Model   $stair_step_setting
     *
     * @return Response
     */
    public function restore(StairStepSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('stair_step_setting::stair_step_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/stair_step_setting/stair_step_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/stair_step_setting/stair_step_setting/'))
                ->redirect();
        }

    }

}
